casefold_encrypt_hash_filename

Function casefold_encrypt_hash_filename 

pub fn casefold_encrypt_hash_filename(
    filename: &CasefoldStr,
    dirhash_key: &[u8; 16],
) -> u32
Hashes a filename for direntry indexing when both encryption and casefolding are enabled. Under this configuration, we need to avoid the hash_code leaking details of the filename but we also need it to be case insensitive so we cannot simply hash the encrypted form.